Checks that all input catalogs share the same type,
counts_or_density, ref_genome, and region, then cbinds their
matrices and re-applies the shared attributes.
Checks that all input catalogs share the same type,
counts_or_density, ref_genome, and region, then cbinds their
matrices and re-applies the shared attributes.