Returns TRUE if x is a numeric matrix with the five catalog
attributes (type, counts_or_density, ref_genome, region,
abundance) and canonical rownames for its type.
Returns TRUE if x is a numeric matrix with the five catalog
attributes (type, counts_or_density, ref_genome, region,
abundance) and canonical rownames for its type.